// LICENSE : MIT
"use strict";
import { TextlintRuleSeverityLevelKeys } from "../context/TextlintRuleSeverityLevelKeys";
var isSeverityLevelValue = function (type) {
    if (type === undefined) {
        throw new Error("Please set following value to severity:\n\"rule-key\": {\n    \"severity\": \"<warning|error>\"\n}");
    }
    return true;
};
/**
 * get severity level from ruleConfig.
 * @param {Object|boolean|undefined} ruleConfig
 * @returns {number}
 */
export function getSeverity(ruleConfig) {
    if (ruleConfig === undefined) {
        return TextlintRuleSeverityLevelKeys.error;
    }
    // rule:<true|false>
    if (typeof ruleConfig === "boolean") {
        return ruleConfig ? TextlintRuleSeverityLevelKeys.error : TextlintRuleSeverityLevelKeys.none;
    }
    if (ruleConfig.severity) {
        var severityValue = TextlintRuleSeverityLevelKeys[ruleConfig.severity];
        if (!isSeverityLevelValue(severityValue)) {
            throw new Error("Please set following value to severity:\n\"rule-key\": {\n    \"severity\": \"<warning|error>\"\n}");
        }
        return severityValue;
    }
    return TextlintRuleSeverityLevelKeys.error;
}
//# sourceMappingURL=rule-severity.js.map